betamcConfidence Intervals Method for an Object of Class
betamc
# S3 method for betamc
confint(object, parm = NULL, level = 0.95, ...)Returns a matrix of confidence intervals.
Object of Class betamc,
that is,
the output of the
BetaMC(),
RSqMC(),
SCorMC(),
DeltaRSqMC(),
PCorMC(), or
DiffBetaMC()
functions.
a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
the confidence level required.
additional arguments.
Ivan Jacob Agaloos Pesigan