Learn R Programming

betaMC (version 1.3.3)

print.betamc: Print Method for an Object of Class betamc

Description

Print Method for an Object of Class betamc

Usage

# S3 method for betamc
print(x, alpha = NULL, digits = 4, ...)

Value

Prints a matrix of estimates, standard errors, number of Monte Carlo replications, and confidence intervals.

Arguments

x

Object of Class betamc, that is, the output of the BetaMC(), RSqMC(), SCorMC(), DeltaRSqMC(), PCorMC(), or DiffBetaMC() functions.

alpha

Numeric vector. Significance level \(\alpha\). If alpha = NULL, use the argument alpha used in x.

digits

Digits to print.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan