Learn R Programming

betaMC (version 1.3.3)

summary.betamc: Summary Method for an Object of Class betamc

Description

Summary Method for an Object of Class betamc

Usage

# S3 method for betamc
summary(object, alpha = NULL, digits = 4, ...)

Value

Returns a matrix of estimates, standard errors, number of Monte Carlo replications, and confidence intervals.

Arguments

object

Object of Class betamc, that is, the output of the BetaMC(), RSqMC(), SCorMC(), DeltaRSqMC(), PCorMC(), or DiffBetaMC() functions.

alpha

Numeric vector. Significance level \(\alpha\). If alpha = NULL, use the argument alpha used in object.

digits

Digits to print.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan