Learn R Programming

betaMC (version 1.3.3)

vcov.betamc: Sampling Variance-Covariance Matrix Method for an Object of Class betamc

Description

Sampling Variance-Covariance Matrix Method for an Object of Class betamc

Usage

# S3 method for betamc
vcov(object, ...)

Value

Returns the variance-covariance matrix of estimates.

Arguments

object

Object of Class betamc, that is, the output of the BetaMC(), RSqMC(), SCorMC(), DeltaRSqMC(), PCorMC(), or DiffBetaMC() functions.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan