Learn R Programming

betaMC (version 1.3.3)

coef.betamc: Estimated Parameter Method for an Object of Class betamc

Description

Estimated Parameter Method for an Object of Class betamc

Usage

# S3 method for betamc
coef(object, ...)

Value

Returns a vector of estimated parameters.

Arguments

object

Object of Class betamc, that is, the output of the BetaMC(), RSqMC(), SCorMC(), DeltaRSqMC(), PCorMC(), or DiffBetaMC() functions.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan