powered by
betamc
Estimated Parameter Method for an Object of Class betamc
# S3 method for betamc coef(object, ...)
Returns a vector of estimated parameters.
Object of Class betamc, that is, the output of the BetaMC(), RSqMC(), SCorMC(), DeltaRSqMC(), PCorMC(), or DiffBetaMC() functions.
BetaMC()
RSqMC()
SCorMC()
DeltaRSqMC()
PCorMC()
DiffBetaMC()
additional arguments.
Ivan Jacob Agaloos Pesigan