powered by
betamc
Sampling Variance-Covariance Matrix Method for an Object of Class betamc
# S3 method for betamc vcov(object, ...)
Returns the variance-covariance matrix of estimates.
Object of Class betamc, that is, the output of the BetaMC(), RSqMC(), SCorMC(), DeltaRSqMC(), PCorMC(), or DiffBetaMC() functions.
BetaMC()
RSqMC()
SCorMC()
DeltaRSqMC()
PCorMC()
DiffBetaMC()
additional arguments.
Ivan Jacob Agaloos Pesigan